@@ -201,6 +201,12 @@ uint32_t diff_geojson(const std::string& file1, const std::string& file2, int32_
         else if (buf2.rfind("GEOGCRS[", 0) == 0)
             buf2ignore = true;
 
+        // remove line endings from test comparisons
+        buf1.erase(std::remove(buf1.begin(), buf1.end(), '\r' ), buf1.end());
+        buf1.erase(std::remove(buf1.begin(), buf1.end(), '\n' ), buf1.end());
+        buf2.erase(std::remove(buf2.begin(), buf2.end(), '\r' ), buf2.end());
+        buf2.erase(std::remove(buf2.begin(), buf2.end(), '\n' ), buf2.end());
+
         if (!buf1ignore && !buf2ignore && buf1 != buf2)
             ++numdiffs;
 
